##
# .test.test_libloop
##
from .. import libloop
from . import mock

def test_events(test):
	test.fail_if_not_hasattr(libloop.events, 'terminate')
	test.fail_if_not_hasattr(libloop.events, 'exhaust')
	test.fail_if_not_hasattr(libloop.events, 'transfer')

def test_activity_in(test):
	m = mock.Transit()
	m.link = object()
	res = [1,-2,3,-4,5]
	m.acquire(res)
	m.mtransfer = slice(2,4)
	m.mevents = (libloop.events.transfer, libloop.events.terminate,)
	m.mfailure = ("kevent", 0)
	m.terminated = True
	a = libloop.activity(m)

	test.fail_if_not_exact(a.transit, m)
	test.fail_if_not_exact(a.link, m.link)
	test.fail_if_not_equal(a.termination, ("kevent", 0))
	test.fail_if_not_equal(a.transferred, [3,-4])
	test.fail_if_not_exact(a.demand, None)

def test_activity_out(test):
	m = mock.Transit()
	m.polarity = False
	m.link = object()
	res = [1,-2,3,-4,5]
	m.acquire(res)
	m.mtransfer = slice(1,4)
	m.mevents = (libloop.events.transfer, libloop.events.exhaust,)
	m.mfailure = (None, 0)
	m.terminated = False
	a = libloop.activity(m)

	test.fail_if_not_exact(a.transit, m)
	test.fail_if_not_exact(a.link, m.link)
	test.fail_if_not_exact(a.termination, None)
	test.fail_if_not_equal(a.transferred, 3)
	test.fail_if_not_exact(a.demand.__func__, m.acquire.__func__)

# NOTE: cycle() and snapshot() are covered by test_lib.

if __name__ == '__main__':
	from dev import libtest; libtest.execmodule()
